*********************
``matplotlib.colors``
*********************

For a visual representation of the Matplotlib colormaps, see:

* The :ref:`color_examples` examples for examples of controlling color with
  Matplotlib.
* The :ref:`tutorials-colors` tutorial for an in-depth guide on controlling
  color.


.. currentmodule:: matplotlib.colors

.. automodule:: matplotlib.colors
   :no-members:
   :no-inherited-members:

Classes
-------

.. autosummary::
   :toctree: _as_gen/
   :template: autosummary.rst

   BoundaryNorm
   Colormap
   DivergingNorm
   LightSource
   LinearSegmentedColormap
   ListedColormap
   LogNorm
   NoNorm
   Normalize
   PowerNorm
   SymLogNorm

Functions
---------

.. autosummary::
   :toctree: _as_gen/
   :template: autosummary.rst

   from_levels_and_colors
   hsv_to_rgb
   rgb_to_hsv
   to_hex
   to_rgb
   to_rgba
   to_rgba_array
   is_color_like
   makeMappingArray
   get_named_colors_mapping
